class WAMArmStand extends KRobot config(USARBot);

//Stereo camera vars
var config bool isStereo;
var config vector stereoSpacing; //(eye to eye)/2 spacing in UU
var config float CameraZoom;
var vector uuStereoSpacing;


simulated function ConvertParam(USARConverter converter)
{
    Super.ConvertParam(converter);
    if(converter!=None)
    {
        uuStereoSpacing = converter.LengthVectorToUU(stereoSpacing);
    }
    else
    {
        uuStereoSpacing = stereoSpacing;
    }

    // If we are using stereo vision, we need to add a camera
    if(isStereo)
    {
	Cameras.Insert(Cameras.length, 1);

	Cameras[Cameras.length-1].ItemClass=Cameras[0].ItemClass;
	Cameras[Cameras.length-1].Parent=Cameras[0].Parent;
	Cameras[Cameras.length-1].ItemName = "StereoCamera";
	Cameras[Cameras.length-1].Position=Cameras[0].Position;
	Cameras[Cameras.length-1].Direction=Cameras[0].Direction;

	Cameras[0].Position -= stereoSpacing;
	Cameras[Cameras.length-1].Position += stereoSpacing;
    }
}


//(Called by KRobot Tick function)
//Stereo vision when viewing from multiview robot camera
simulated function SyncMultiView()
{
    if(ViewManager != none)
    {
        if(isStereo)
            ViewManager.UpdateView(ViewNum, myCamera.Location, myCamera.Rotation, 
		CamList[0].CameraFov, true, uuStereoSpacing);
        else
            ViewManager.UpdateView(ViewNum, myCamera.Location, myCamera.Rotation,
                                   CameraZoom, false);
    }
}

//*********************************************************************************************************************
// DEFAULT PROPERTIES
//*********************************************************************************************************************
defaultproperties
{
    StaticMesh=StaticMesh'USARSim_Vehicles_Meshes.WAMArm.Stand'
    DrawScale=1
    stereoSpacing=(Y=0.05) //5 cm: (eye to eye)/2 spacing in meter
    CameraZoom = 1.0
    isStereo= true

    Begin Object Class=KarmaParamsRBFull Name=KParams0
        KActorGravScale=2.58
        bKNonSphericalInertia=True
        KInertiaTensor(0)=5
        KInertiaTensor(3)=5
        KInertiaTensor(5)=5
        KCOMOffset=(X=0.2,Y=0.0,Z=0.0)
        KLinearDamping=0
        KAngularDamping=10000
        KMaxAngularSpeed=0
        KMaxSpeed=25000
        KStartEnabled=True
        bHighDetailOnly=False
        bClientOnly=False
        bKDoubleTickRate=True
        KFriction=0.9
        bKStayUpright=True
        Name="KParams0"
    End Object
    KParams=KarmaParamsRBFull'USARBot.WAMArmStand.KParams0'
}